summaryrefslogtreecommitdiff
path: root/gtk/about_dlg.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2006-05-22 07:29:40 +0000
committerGuy Harris <guy@alum.mit.edu>2006-05-22 07:29:40 +0000
commit92552c2d765dcf89883392fcd11556d54f2843e5 (patch)
treebb7476c5cd4845fce70a943d87cab8ddb12fe41d /gtk/about_dlg.h
parent4c4664721edb7f9f7b9886a881d913e4dff2043a (diff)
downloadwireshark-92552c2d765dcf89883392fcd11556d54f2843e5.tar.gz
Get rid of a bunch of "Ethereal"s and "ethereal"s in comments, GUI
strings, and function names. svn path=/trunk/; revision=18205
Diffstat (limited to 'gtk/about_dlg.h')
-rw-r--r--gtk/about_dlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk/about_dlg.h b/gtk/about_dlg.h
index 65070a22a3..7744865690 100644
--- a/gtk/about_dlg.h
+++ b/gtk/about_dlg.h
@@ -30,7 +30,7 @@
* @ingroup dialog_group
*/
/** Create a splash screen showed when Ethereal is started.
*
* @param message the new message to be displayed
* @return the newly created window handle
@@ -56,7 +56,7 @@ extern guint splash_destroy(GtkWidget *win);
* @param widget parent widget (unused)
* @param data unused
*/
-extern void about_ethereal_cb( GtkWidget *widget, gpointer data);
+extern void about_wireshark_cb( GtkWidget *widget, gpointer data);
#endif /* __ABOUT_DLG_H__ */
@@ -30,7 +30,7 @@
* @ingroup dialog_group
*/
-/** Create a splash screen showed when Ethereal is started.
+/** Create a splash screen showed when Wireshark is started.
*
* @param message the new message to be displayed